
.. If you created a package, create one automodule per module in the package.

.. If your library file(s) are nested in a directory (e.g. /adafruit_foo/foo.py)
.. use this format as the module name: "adafruit_foo.foo"

.. automodule:: adafruit_led_animation.animation
   :members:

.. automodule:: adafruit_led_animation.color
   :members:

.. automodule:: adafruit_led_animation.helper
   :members:

.. automodule:: adafruit_led_animation.group
   :members:

.. automodule:: adafruit_led_animation.sequence
   :members:

.. automodule:: adafruit_led_animation.animation.blink
   :members:

.. automodule:: adafruit_led_animation.animation.solid
   :members:

.. automodule:: adafruit_led_animation.animation.colorcycle
   :members:

.. automodule:: adafruit_led_animation.animation.chase
   :members:

.. automodule:: adafruit_led_animation.animation.comet
   :members:

.. automodule:: adafruit_led_animation.animation.pulse
   :members:

.. automodule:: adafruit_led_animation.animation.rainbow
   :members:

.. automodule:: adafruit_led_animation.animation.sparkle
   :members:

.. automodule:: adafruit_led_animation.animation.rainbowchase
   :members:

.. automodule:: adafruit_led_animation.animation.rainbowcomet
   :members:

.. automodule:: adafruit_led_animation.animation.rainbowsparkle
   :members:

.. automodule:: adafruit_led_animation.animation.sparklepulse
   :members:
